@@ -3,13 +3,9 @@ from django.views.generic.edit import CreateView as _CreateView, UpdateView as _
 
 from forms import transactional_save
 
+
 class TransactionalModelFormMixin(object):
     def validationerror_from_integrityerror(self, ierror):
-        if hasattr(ierror, 'cause'):
-            cause = ierror.cause
-            ret = try_postgresql(ierror, self)
-            if ret is not None:
-                return ret
         return None
 
     def form_valid(self, form):
